#
# spec file for package gitsign
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           gitsign
Version:        0.8.0
Release:        1.1
Summary:        Keyless Git signing using Sigstore
License:        Apache-2.0
URL:            https://github.com/sigstore/gitsign
Source:         gitsign-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.20

%description
Keyless Git signing with Sigstore!

This is heavily inspired by https://github.com/github/smimesign, but uses keyless Sigstore to sign Git commits with your own GitHub / OIDC identity.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/sigstore/gitsign/pkg/version.gitVersion=%{version}" \
   -o bin/gitsign .

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Fri Nov 10 2023 kastl@b1-systems.de
- Update to version 0.8.0:
  * Add options for Rekor client, make public key fetcher
    configurable. (#399)
  * Bump github.com/sigstore/cosign/v2 from 2.2.0 to 2.2.1 (#400)
  * Bump github.com/spf13/cobra from 1.7.0 to 1.8.0 (#397)
  * Bump github.com/sigstore/rekor from 1.3.2 to 1.3.3 (#398)
  * Bump github.com/docker/docker (#396)
  * Bump github.com/sigstore/sigstore from 1.7.4 to 1.7.5 (#394)
  * Bump github.com/go-git/go-git/v5 from 5.9.0 to 5.10.0 (#395)
  * Bump actions/checkout from 4.1.0 to 4.1.1 (#393)
  * Bump github.com/coreos/go-oidc/v3 from 3.6.0 to 3.7.0 (#392)
  * Bump github.com/sigstore/fulcio from 1.4.0 to 1.4.3 (#389)
  * Bump github.com/sigstore/sigstore from 1.7.3 to 1.7.4 (#388)
  * Bump golang.org/x/oauth2 from 0.12.0 to 0.13.0 (#385)
  * Bump github.com/sigstore/rekor from 1.3.0 to 1.3.2 (#390)
  * Bump github.com/google/go-cmp from 0.5.9 to 0.6.0 (#391)
  * Bump golang.org/x/net from 0.15.0 to 0.17.0 (#387)
  * Bump golang.org/x/crypto from 0.13.0 to 0.14.0 (#386)
  * upgrade to go1.21 (#383)
  * Bump e2e github actions workflows to go 1.21 (#384)
  * Bump actions/checkout from 4.0.0 to 4.1.0 (#381)
  * Bump github.com/go-git/go-git/v5 from 5.8.1 to 5.9.0 (#379)
  * Bump goreleaser/goreleaser-action from 4.6.0 to 5.0.0 (#380)
  * Bump actions/checkout from 3.6.0 to 4.0.0 (#375)
  * Bump goreleaser/goreleaser-action from 4.4.0 to 4.6.0 (#373)
  * Bump golang.org/x/oauth2 from 0.11.0 to 0.12.0 (#377)
  * Bump actions/cache from 3.3.1 to 3.3.2 (#374)
  * Bump github.com/sigstore/rekor from 1.2.2 to 1.3.0 (#370)
  * Bump github.com/sigstore/cosign/v2 from 2.1.1 to 2.2.0 (#372)
  * Bump github.com/sigstore/sigstore from 1.7.2 to 1.7.3 (#371)
  * Bump sigstore/cosign-installer from 3.1.1 to 3.1.2 (#369)
  * Bump actions/checkout from 3.5.3 to 3.6.0 (#368)
  * Bump golangci/golangci-lint-action from 3.6.0 to 3.7.0 (#366)
  * Bump github.com/sigstore/protobuf-specs from 0.2.0 to 0.2.1
    (#367)
  * Bump actions/setup-go from 4.0.1 to 4.1.0 (#362)
  * Bump goreleaser/goreleaser-action from 4.3.0 to 4.4.0 (#363)
  * Bump github.com/sigstore/sigstore from 1.7.1 to 1.7.2 (#361)
  * Bump golang.org/x/oauth2 from 0.10.0 to 0.11.0 (#360)
  * Bump golang.org/x/crypto from 0.11.0 to 0.12.0 (#359)
  * Bump github.com/go-git/go-git/v5 from 5.8.0 to 5.8.1 (#358)
  * Bump github.com/go-git/go-git/v5 from 5.7.0 to 5.8.0 (#356)
  * Bump github.com/sigstore/fulcio from 1.3.4 to 1.4.0 (#357)
  * Updates to avoid values appearing in certificates (#354)
  * Bump github.com/sigstore/fulcio from 1.3.3 to 1.3.4 (#351)
  * Bump github.com/secure-systems-lab/go-securesystemslib (#353)
  * Bump github.com/sigstore/protobuf-specs from 0.1.0 to 0.2.0
    (#352)
  * Bump golang.org/x/oauth2 from 0.9.0 to 0.10.0 (#349)
  * Bump github.com/sigstore/fulcio from 1.3.2 to 1.3.3 (#348)
  * Bump github.com/sigstore/fulcio from 1.3.1 to 1.3.2 (#345)
  * Bump dependabot/fetch-metadata from 1.5.1 to 1.6.0 (#343)
  * Bump github.com/sigstore/rekor (#347)
  * Bump github.com/sigstore/cosign/v2 from 2.1.0 to 2.1.1 (#344)
  * Bump sigstore/cosign-installer from 3.1.0 to 3.1.1 (#342)
  * Bump github.com/sigstore/sigstore from 1.7.0 to 1.7.1 (#340)
  * Bump github.com/sigstore/cosign/v2 (#341)
  * Bump anchore/sbom-action from 0.14.2 to 0.14.3 (#339)
  * Bump sigstore/cosign-installer from 3.0.5 to 3.1.0 (#338)
  * Bump goreleaser/goreleaser-action from 4.2.0 to 4.3.0 (#333)
  * Bump golangci/golangci-lint-action from 3.5.0 to 3.6.0 (#334)
  * Bump github.com/sigstore/sigstore from 1.6.5 to 1.7.0 (#337)
  * Bump golang.org/x/crypto from 0.9.0 to 0.10.0 (#336)
  * Bump github.com/go-openapi/swag from 0.22.3 to 0.22.4 (#332)
  * Bump actions/checkout from 3.5.2 to 3.5.3 (#331)
  * Fix offline verification marshalling, add e2e tests. (#330)
  * update sigstore/sigstore and cosign (#329)
  * Bump golangci/golangci-lint-action from 3.4.0 to 3.5.0 (#327)
  * Bump dependabot/fetch-metadata from 1.4.0 to 1.5.1 (#323)
  * Bump github.com/go-git/go-git/v5 from 5.6.1 to 5.7.0 (#325)
  * Bump github.com/sigstore/rekor from 1.2.0 to 1.2.1 (#324)
  * Bump github.com/sigstore/rekor from 1.1.1 to 1.2.0 (#322)
  * Add gitsign initialize. (#321)
* Tue May 23 2023 kastl@b1-systems.de
- Update to version 0.7.1:
  * Offline verification: refactor to make it clear no signature
    checks are happening. (#319)
  * Revoke v0.7.0 (#318)
* Tue May 23 2023 kastl@b1-systems.de
- Update to version 0.7.0:
  * Bump github.com/jonboulle/clockwork from 0.3.0 to 0.4.0 (#316)
  * Add offline verification (#220)
  * Bump github.com/coreos/go-oidc/v3 from 3.5.0 to 3.6.0 (#314)
  * Bump sigstore/cosign-installer from 3.0.3 to 3.0.5 (#313)
  * Bump actions/setup-go from 4.0.0 to 4.0.1 (#312)
  * Bump golang.org/x/crypto from 0.8.0 to 0.9.0 (#310)
  * Bump golang.org/x/oauth2 from 0.7.0 to 0.8.0 (#311)
  * Bump github.com/docker/distribution (#309)
  * Bump github.com/cloudflare/circl from 1.3.1 to 1.3.3 (#308)
  * Bump github.com/sigstore/fulcio from 1.2.0 to 1.3.1 (#302)
  * Bump github.com/sigstore/sigstore from 1.6.3 to 1.6.4 (#304)
  * Bump github.com/in-toto/in-toto-golang from 0.8.0 to 0.9.0
    (#305)
  * Bump anchore/sbom-action from 0.14.1 to 0.14.2 (#307)
  * Bump github.com/mattn/go-tty from 0.0.4 to 0.0.5 (#306)
  * Bump github.com/sigstore/rekor from 1.1.0 to 1.1.1 (#300)
  * Bump github.com/in-toto/in-toto-golang from 0.7.1 to 0.8.0
    (#298)
  * Bump github.com/sigstore/cosign/v2 from 2.0.1 to 2.0.2 (#299)
  * Bump sigstore/cosign-installer from 3.0.2 to 3.0.3 (#297)
  * Bump actions/checkout from 3.5.0 to 3.5.2 (#289)
  * Bump github.com/sigstore/sigstore from 1.6.2 to 1.6.3 (#296)
  * Bump github.com/go-openapi/runtime from 0.25.0 to 0.26.0 (#295)
  * Bump dependabot/fetch-metadata from 1.3.6 to 1.4.0 (#294)
  * Ensure that io writers are properly closed. (#292)
  * Bump github.com/sigstore/sigstore from 1.6.1 to 1.6.2 (#290)
  * Fix e2e test for initializing cosign (#287)
  * Update e2e test to use CDN instead of GCS (#285)
  * Bump golang.org/x/crypto from 0.7.0 to 0.8.0 (#283)
* Mon May  1 2023 Johannes Kastl <kastl@b1-systems.de>
- new package gitsign: Keyless Git signing using Sigstore
